CheckCommand

Struct CheckCommand 

pub struct CheckCommand {
    pub fix: bool,
    pub unsafe_fixes: bool,
    pub add_ignore: Option<String>,
    pub output_format: CheckOutputFormatArg,
    pub watch: bool,
    pub paths: Vec<PathBuf>,
    pub rule_selection: RuleSelectionArgs,
    pub file_selection: FileSelectionArgs,
    pub no_cache: bool,
    pub exit_zero: bool,
    pub exit_non_zero_on_fix: bool,
}
Arguments for shuck check.

Fields

fix: bool

Apply safe fixes.

unsafe_fixes: bool

Apply unsafe fixes.

add_ignore: Option<String>

Enable automatic additions of shuck ignore directives to failing lines. Optionally provide a reason to append after the codes.

output_format: CheckOutputFormatArg

Output serialization format for violations. The default serialization format is “full”.

watch: bool

Run in watch mode by re-running whenever files change.

paths: Vec<PathBuf>

Files or directories to check.

rule_selection: RuleSelectionArgs

Rule selection and suppression settings.

file_selection: FileSelectionArgs

File discovery and exclusion settings.

no_cache: bool

Disable cache reads and writes.

exit_zero: bool

Exit with status code “0”, even upon detecting lint violations. Parse errors and error-severity diagnostics still fail.

exit_non_zero_on_fix: bool

Exit with a non-zero status code if any files were modified via fix, even if no lint violations remain.

Implementations

Source

impl CheckCommand

pub fn respect_gitignore(&self) -> bool

Whether standard ignore files such as .gitignore should be respected.

pub fn force_exclude(&self) -> bool

Whether excludes should also apply to explicitly passed paths.