pub struct FormatCommand {
pub files: Vec<PathBuf>,
pub check: bool,
pub diff: bool,
pub no_cache: bool,
pub stdin_filename: Option<PathBuf>,
pub file_selection: FileSelectionArgs,
pub dialect: Option<FormatDialectArg>,
pub indent_style: Option<FormatIndentStyleArg>,
pub indent_width: Option<u8>,
pub simplify: bool,
pub minify: bool,
/* private fields */
}Expand description
Arguments for shuck format.
Fields
files: Vec<PathBuf>List of files or directories to format, or - to read from stdin.
check: boolAvoid writing any formatted files back; instead, exit non-zero if any files would change.
diff: boolAvoid writing any formatted files back; instead, print a diff for each changed file.
no_cache: boolDisable cache reads and writes.
stdin_filename: Option<PathBuf>The name of the file when reading the source from stdin.
file_selection: FileSelectionArgsFile discovery and exclusion settings.
dialect: Option<FormatDialectArg>Override the auto-discovered shell dialect used for parsing and formatting.
indent_style: Option<FormatIndentStyleArg>Choose the indentation style.
indent_width: Option<u8>Set the indentation width for space indentation.
simplify: boolApply safe simplifications before formatting.
minify: boolEmit a compact minified form and drop comments.
Implementations
Sourceimpl FormatCommand
impl FormatCommand
Sourcepub fn binary_next_line(&self) -> Option<bool>
pub fn binary_next_line(&self) -> Option<bool>
Resolve the effective binary-next-line formatter option.
Sourcepub fn switch_case_indent(&self) -> Option<bool>
pub fn switch_case_indent(&self) -> Option<bool>
Resolve the effective switch-case-indent formatter option.
Sourcepub fn space_redirects(&self) -> Option<bool>
pub fn space_redirects(&self) -> Option<bool>
Resolve the effective space-redirects formatter option.
Sourcepub fn keep_padding(&self) -> Option<bool>
pub fn keep_padding(&self) -> Option<bool>
Resolve the effective keep-padding formatter option.
Sourcepub fn function_next_line(&self) -> Option<bool>
pub fn function_next_line(&self) -> Option<bool>
Resolve the effective function-next-line formatter option.
Sourcepub fn never_split(&self) -> Option<bool>
pub fn never_split(&self) -> Option<bool>
Resolve the effective never-split formatter option.
Sourcepub fn respect_gitignore(&self) -> bool
pub fn respect_gitignore(&self) -> bool
Whether standard ignore files such as .gitignore should be respected.
Sourcepub fn force_exclude(&self) -> bool
pub fn force_exclude(&self) -> bool
Whether excludes should also apply to explicitly passed paths.