pub struct InstallCommand {
pub list: bool,
pub refresh: bool,
pub shell: Option<ManagedShellArg>,
pub version: Option<String>,
}Expand description
Arguments for shuck install.
Fields
list: boolShow available shells and versions instead of installing anything.
refresh: boolForce a fresh registry fetch even if the local registry cache is still fresh.
shell: Option<ManagedShellArg>Shell interpreter name (bash, gbash, bashkit, zsh, dash, mksh, or Linux-only busybox).
version: Option<String>Version constraint to install.