pub struct RuleSelectionArgs {
pub select: Option<Vec<RuleSelector>>,
pub ignore: Vec<RuleSelector>,
pub extend_select: Vec<RuleSelector>,
pub per_file_ignores: Option<Vec<PatternRuleSelectorPair>>,
pub extend_per_file_ignores: Vec<PatternRuleSelectorPair>,
pub fixable: Option<Vec<RuleSelector>>,
pub unfixable: Vec<RuleSelector>,
pub extend_fixable: Vec<RuleSelector>,
}Expand description
Rule-selection flags shared by shuck check.
Fields
select: Option<Vec<RuleSelector>>Comma-separated list of rule codes to enable (or ALL, to enable all rules).
ignore: Vec<RuleSelector>Comma-separated list of rule codes to disable.
extend_select: Vec<RuleSelector>Like –select, but adds additional rule codes on top of those already specified.
per_file_ignores: Option<Vec<PatternRuleSelectorPair>>List of mappings from file pattern to code to exclude.
extend_per_file_ignores: Vec<PatternRuleSelectorPair>Like --per-file-ignores, but adds additional ignores on top of those already specified.
fixable: Option<Vec<RuleSelector>>List of rule codes to treat as eligible for fix. Only applicable when fix itself is enabled (e.g., via --fix).
unfixable: Vec<RuleSelector>List of rule codes to treat as ineligible for fix. Only applicable when fix itself is enabled (e.g., via --fix).
extend_fixable: Vec<RuleSelector>Like –fixable, but adds additional rule codes on top of those already specified.