pub struct ZshPluginArgs {
pub zsh_plugin_root: Option<Vec<FrameworkRootPair>>,
pub extend_zsh_plugin_root: Vec<FrameworkRootPair>,
pub zsh_plugin: Option<Vec<PatternFrameworkNameTriple>>,
pub extend_zsh_plugin: Vec<PatternFrameworkNameTriple>,
pub zsh_theme: Option<Vec<PatternFrameworkNameTriple>>,
pub extend_zsh_theme: Vec<PatternFrameworkNameTriple>,
pub zsh_plugin_entrypoint: Option<Vec<PatternPathPair>>,
pub extend_zsh_plugin_entrypoint: Vec<PatternPathPair>,
/* private fields */
}Expand description
Zsh plugin-resolution flags shared by shuck check.
Fields
zsh_plugin_root: Option<Vec<FrameworkRootPair>>Replace configured zsh plugin roots with the provided framework-to-path mappings.
extend_zsh_plugin_root: Vec<FrameworkRootPair>Add or replace individual zsh plugin roots on top of earlier config or CLI values.
zsh_plugin: Option<Vec<PatternFrameworkNameTriple>>Replace configured logical zsh plugin loads with the provided pattern-to-framework-to-name mappings.
extend_zsh_plugin: Vec<PatternFrameworkNameTriple>Add logical zsh plugin loads on top of earlier config or CLI values.
zsh_theme: Option<Vec<PatternFrameworkNameTriple>>Replace configured logical zsh theme loads with the provided pattern-to-framework-to-name mappings.
extend_zsh_theme: Vec<PatternFrameworkNameTriple>Add logical zsh theme loads on top of earlier config or CLI values.
zsh_plugin_entrypoint: Option<Vec<PatternPathPair>>Replace configured raw zsh plugin entrypoints with the provided pattern-to-path mappings.
extend_zsh_plugin_entrypoint: Vec<PatternPathPair>Add raw zsh plugin entrypoints on top of earlier config or CLI values.
Implementations
Sourceimpl ZshPluginArgs
impl ZshPluginArgs
Sourcepub fn resolution(&self) -> Option<bool>
pub fn resolution(&self) -> Option<bool>
Returns the requested zsh plugin-resolution override, if any.