pub struct CheckCommand {
pub fix: bool,
pub unsafe_fixes: bool,
pub add_ignore: Option<String>,
pub output_format: CheckOutputFormatArg,
pub watch: bool,
pub paths: Vec<PathBuf>,
pub rule_selection: RuleSelectionArgs,
pub file_selection: FileSelectionArgs,
pub no_cache: bool,
pub exit_zero: bool,
pub exit_non_zero_on_fix: bool,
}Expand description
Arguments for shuck check.
Fields
fix: boolApply safe fixes.
unsafe_fixes: boolApply unsafe fixes.
add_ignore: Option<String>Enable automatic additions of shuck ignore directives to failing lines. Optionally provide a reason to append after the codes.
output_format: CheckOutputFormatArgOutput serialization format for violations. The default serialization format is “full”.
watch: boolRun in watch mode by re-running whenever files change.
paths: Vec<PathBuf>Files or directories to check.
rule_selection: RuleSelectionArgsRule selection and suppression settings.
file_selection: FileSelectionArgsFile discovery and exclusion settings.
no_cache: boolDisable cache reads and writes.
exit_zero: boolExit with status code “0”, even upon detecting lint violations. Parse errors and error-severity diagnostics still fail.
exit_non_zero_on_fix: boolExit with a non-zero status code if any files were modified via fix, even if no lint violations remain.
Implementations
Sourceimpl CheckCommand
impl CheckCommand
Sourcepub fn respect_gitignore(&self) -> bool
pub fn respect_gitignore(&self) -> bool
Whether standard ignore files such as .gitignore should be respected.
Sourcepub fn force_exclude(&self) -> bool
pub fn force_exclude(&self) -> bool
Whether excludes should also apply to explicitly passed paths.